package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````Z!4!`#0```#`D@````0`!30`(``)
M`"@`'``;``$``'!L@@``;((!`&R"`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0!X@@``>((```4```````$`
M`0```/2.``#TC@(`](X"`"@"``!4$@``!@```````0`"`````(\```"/`@``
MCP(```$````!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D](X`
M`/2.`@#TC@(`#`$```P!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`/V4NT$->!PKR`5GS=,":]!,<%L@$
M````$`````$```!'3E4```````,````"`````````(8````$````$`````D`
M``"@"*0"@^4#E@@JSD@&40`Y@@`"1PHA`!"D0````+)`$`*``@@`D$`@3B""
M(0`@P")``$4TP&0""#07!)T@D4*@``````0`````````!@````<````(````
M``````D````*``````````L````-````````````````````#@`````````/
M````$````````````````````!$````````````````````2````$P``````
M````````%``````````````````````````5`````````!<`````````````
M```````8`````````!D````;````'````!T````>````````````````````
M`````!\````@````(0```"(````C`````````"0````E````)@``````````
M`````````"<````H````````````````````*0``````````````*@```"P`
M`````````````"T````N````+P```#```````````````#$````R````````
M`#,``````````````#4````W`````````#@````````````````````Y````
M`````````````````````````````````````#H````[````/````#T`````
M````/@`````````_````0````$$`````````0@```$0`````````1@``````
M````````````````````````1P````````!(````20```$H`````````````
M````````````2P`````````*BA!7HP+V&6USA<4KT.$BHUKOD#GRBQS-/PRO
MZ/O#PNT_D`('I(?_%^I:\7OP2FN3K01B7Y:3'%>DFY8A=+`"Q;F<0$!-G7RG
MFY,<4>X1XRT.L7/&#N`]G;N3'-OW`%X_?I9\8]#Z@C^>0D19.T`?WX4@3]-1
M!(3).4`?]R/.(+W02WU1&WU?PXZ'__W2[P]+(GW_R=6R<<Y*KO^?(L>H?>T1
M#WV0$.D]K3D-=V_C<`$C^:0O3CWVQ8D%D$)F2Q"!=((-(&)D!Y%U@@V'\)9\
M&Y_6O>TL]HL%,J6%[=Z3')DBU&BGW:-KF4+NH8?YG(%AF.\2+=_^2&YZ:?I7
MDEI2[@M1^5N:.P]#1=7LN^.2?%?;DQPQN((-NY63'-EQ6!P`````````````
M`````````0``````````````(````!T``````````````"`````L````````
M```````@````1@```"B1`@`!````$0`8`%,``````````````!(```!Y`@``
M```````````2````M`(`````````````$@```+(!`````````````!(```"6
M`@``,)$"``0````1`!@`V0$`````````````$@```!<!`````````````!(`
M``",```````````````2````G0(`````````````$@```-0"````````````
M`!(```"7````(!$!```````2````N@$`````````````$@```-L"````````
M`````!(```"*`0``))$"``0````1`!@`C`(`````````````$@```/0"```@
MD0(`!````!$`&`"F`0`````````````2````+0(`````````````$@```%8"
M`````````````!(```!\`0`````````````2````$0(`````````````$@``
M`#L"`````````````!(```#J`0`````````````2````U`$`````````````
M$@````P!`````````````!(```"````````````````2````6`$`````````
M````$@```,D``````````````!(```"P```````````````2````\P$`````
M````````$@````0"`````````````!(```#8```````````````2````NP``
M````````````$@```"8"`````````````!(````+`@`````````````2````
M:P(`````````````$@```&D!``"X$@$``````!(```#A`0`````````````2
M````O@(`````````````$@```!D"`````````````!(```!)`0``````````
M```2````0@$`````````````$@```(0"`````````````!(```"5`0``````
M```````2````X@(`````````````$@```/4"```@D0(`!````"$`&`!0`@``
M```````````2````'P(`````````````$@```!`#``#\C@(`!````!$`%`!D
M`@`````````````2````,0$`````````````$@```,P"`````````````!(`
M```V`0`````````````2````YP``````````````$@```#0"````````````
M`!(````L`0`````````````2````]@(``""1`@`$````(0`8`/4`````````
M`````!(```!O````,!,!```````2````JP$`````````````$@```*<`````
M`````````!(```#^`@`````````````2````8P``````````````$@```*0"
M`````````````!(```#.`0`````````````2````8`,``!R1`@``````$``7
M`',#``!(H0(``````!``&`!)`@`````````````2````0@(`````````````
M$@```*T"`````````````!(```!G`P``')$"```````0`!@``%])5$U?9&5R
M96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES
M=&5R5$U#;&]N951A8FQE`%!,7V1O7W5N9'5M<`!097)L7V=V7V9E=&-H<'8`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?;&]C:P!097)L7V=E=%]S=@!097)L
M7VYE=UA3`&)O;W1?1'EN84QO861E<@!P97)L7W)U;@!P97)L7W!A<G-E`%!E
M<FQ?<W9?<V5T<'8`4&5R;%]S=E]S971P=FX`<&5R;%]C;VYS=')U8W0`<&5R
M;%]D97-T<G5C=`!097)L7V-R;V%K7VUE;6]R>5]W<F%P`'!E<FQ?86QL;V,`
M4&5R;%]C<F]A:U]N;V-O;G1E>'0`<&5R;%]F<F5E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!097)L7W-Y<U]I;FET,P!097)L7VYE=UA37V9L86=S`%!E<FQ?871F
M;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%!,7W1H<E]K97D`7U]E<G)N;U]L
M;V-A=&EO;@!R96%D`&]P96XV-`!L<V5E:S8T`'!T:')E861?9V5T<W!E8VEF
M:6,`8VQO<V4`97AI=`!S=')N8VUP`&=E='!W=6ED`&-L;W-E9&ER`%]?<W1A
M8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR
M`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M
M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T
M870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK
M`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S
M<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T
M97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XS,@!L
M:6)P=&AR96%D+G-O+C``;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`
M7V5D871A`%]?8G-S7W-T87)T`%]E;F0`1TQ)0D-?,BXT````````````````
M``(``@`#``(``@```````@`"`````P`"`````@`"``,``@`"`````@`"``(`
M`@```````````````@`"```````"``(``@````(``@`"`````@`"``,``@`"
M``(``@`$``(``@`"```````"`````@```````P````(````"``,``0`!``(`
M`@`"``$````!``$`3`,``!`````@````%&EI#0``!`!X`P````````$``0`R
M`P``$````"`````4:6D-```#`'@#`````````0`!`$(#```0`````````!1I
M:0T```(`>`,````````(D0(`%0(``/R.`@`4-0``()$"`!04```DD0(`%!(`
M`"B1`@`4!```,)$"`!0)```,D`(`%D@``!"0`@`6$0``%)`"`!8J```8D`(`
M%A4``!R0`@`6#0``()`"`!8X```DD`(`%C<``"B0`@`6-@``+)`"`!8/```P
MD`(`%C,``#20`@`6)```.)`"`!8\```\D`(`%B@``$"0`@`6%@``1)`"`!8B
M``!(D`(`%D(``$R0`@`6(P``4)`"`!89``!4D`(`%CH``%B0`@`6)0``7)`"
M`!9$``!@D`(`%AT``&20`@`6"```:)`"`!8Y``!LD`(`%B\``'"0`@`60```
M=)`"`!8N``!XD`(`%C$``'R0`@`6!0``@)`"`!8"``"$D`(`%B8``(B0`@`6
M'```C)`"`!8:``"0D`(`%BT``)20`@`62@``F)`"`!8>``"<D`(`%C```*"0
M`@`6*P``I)`"`!8+``"HD`(`%@P``*R0`@`6)P``L)`"`!9)``"TD`(`%BD`
M`+B0`@`6&```O)`"`!9#``#`D`(`%B$``,20`@`6%P``R)`"`!8?``#,D`(`
M%C0``-"0`@`6#@``U)`"`!8^``#8D`(`%CL``-R0`@`6/P``X)`"`!8'``#D
MD`(`%B```.B0`@`600``[)`"`!83``#PD`(`%@H``/20`@`6+```^)`"`!9%
M``#\D`(`%@8```"1`@`6&P``!)$"`!80```(0"WI7@$`ZPB`O>@$X"WE!."?
MY0[@C^`(\+[E1'\!``#&C^(7RHSB1/^\Y0#&C^(7RHSB//^\Y0#&C^(7RHSB
M-/^\Y0#&C^(7RHSB+/^\Y0#&C^(7RHSB)/^\Y0#&C^(7RHSB'/^\Y0#&C^(7
MRHSB%/^\Y0#&C^(7RHSB#/^\Y0#&C^(7RHSB!/^\Y0#&C^(7RHSB_/Z\Y0#&
MC^(7RHSB]/Z\Y0#&C^(7RHSB[/Z\Y0#&C^(7RHSBY/Z\Y0#&C^(7RHSBW/Z\
MY0#&C^(7RHSBU/Z\Y0#&C^(7RHSBS/Z\Y0#&C^(7RHSBQ/Z\Y0#&C^(7RHSB
MO/Z\Y0#&C^(7RHSBM/Z\Y0#&C^(7RHSBK/Z\Y0#&C^(7RHSBI/Z\Y0#&C^(7
MRHSBG/Z\Y0#&C^(7RHSBE/Z\Y0#&C^(7RHSBC/Z\Y0#&C^(7RHSBA/Z\Y0#&
MC^(7RHSB?/Z\Y0#&C^(7RHSB=/Z\Y0#&C^(7RHSB;/Z\Y0#&C^(7RHSB9/Z\
MY0#&C^(7RHSB7/Z\Y0#&C^(7RHSB5/Z\Y0#&C^(7RHSB3/Z\Y0#&C^(7RHSB
M1/Z\Y0#&C^(7RHSB//Z\Y0#&C^(7RHSB-/Z\Y0#&C^(7RHSB+/Z\Y0#&C^(7
MRHSB)/Z\Y0#&C^(7RHSB'/Z\Y0#&C^(7RHSB%/Z\Y0#&C^(7RHSB#/Z\Y0#&
MC^(7RHSB!/Z\Y0#&C^(7RHSB_/V\Y0#&C^(7RHSB]/V\Y0#&C^(7RHSB[/V\
MY0#&C^(7RHSBY/V\Y0#&C^(7RHSBW/V\Y0#&C^(7RHSBU/V\Y0#&C^(7RHSB
MS/V\Y0#&C^(7RHSBQ/V\Y0#&C^(7RHSBO/V\Y0#&C^(7RHSBM/V\Y0#&C^(7
MRHSBK/V\Y0#&C^(7RHSBI/V\Y0#&C^(7RHSBG/V\Y0#&C^(7RHSBE/V\Y0#&
MC^(7RHSBC/V\Y0#&C^(7RHSBA/V\Y0#&C^(7RHSB?/V\Y0#&C^(7RHSB=/V\
MY0#&C^(7RHSB;/V\Y0#&C^(7RHSB9/V\Y0#&C^(7RHSB7/V\Y0#&C^(7RHSB
M5/V\Y0````!P0"WI(#*?Y2#03>(4`(WE%`"-XA`0C>40$(WB#""-Y0P@C>(`
M,)/E'#"-Y0`PH..7___KN"(!XP$@0.,"$*#A,`,!XP$`0./+"P#K*#$)XP(P
M0.,`4-/E``!5XTX```HD00GC`D!`XP``E.7?___K`#"@X0``E.7&(]/E`B""
MX\8CP^79___K%&"=Y<8ST.4$((;B`V"&X@$P@^,'`7+CQC/`Y5H``(H"`:#A
M.%$)XP)00.-8___K$$"=Y00`A>4`,)3E`#"`Y0PW!.,!,$#C!#"`Y10Q">,"
M,$#C!#"3Y0@P@.40-P3C`3!`XPPP@.44,)WE`0!3XT8``-H#,:#A!!"$X@S`
M@.(#0(3@!."1Y`3@K.4$`%'A^___&@PP@^(`$*#C`!"-Y08@H.$#$(#G`#"@
MX8P=`>,!$$#C#`"5Y7?__^L`0%#B(```"@P`E>4B___K&!"-XMP$!.,!`$#C
M;@``ZP``4.,<```*#`"5Y07__^MD___KK#"?Y0`@D^4<,)WE`B`SX``PH.,C
M```:!`"@X2#0C>)P@+WH&/__ZS@A">,"($#C``!0XPP`@N4;```*)$$)XP)`
M0./O_O_K``"4Y8G__^M]5\#EI?__Z@P`E>5P___K`$"@X=K__^H(`)7E``!0
MXP$```H0!P#KW?__ZA@0C>)\!`3C`0!`XT8``.L``%#C"`"%Y=;__PKU___J
M4?__ZQ`PH..____JXO[_ZP$`H.,3___K_(X"``"PH.,`X*#C!!"=Y`T@H.$$
M("WE!``MY1#`G^4$P"WE#`"?Y0PPG^7[_O_K5___ZS!#`0"X$P$`S$(!`!0P
MG^44()_E`S"/X`(@D^<``%+C'O\O`?;^_^K,>0$`"`$``!P!">,"`$#C'#$)
MXP(P0.,``%/A'O\O`0`P`.,`,$#C``!3XQ[_+P$3_R_A'`$)XP(`0.,<$0GC
M`A!`XP`P0>"C'Z#A0Q&!X,$0L.$>_R\!`#``XP`P0.,``%/C'O\O`1/_+^$0
M0"WI-$$)XP)`0.,`,-3E``!3XQ"`O1C?___K`3"@XP`PQ.40@+WHYO__ZO!'
M+>D`D%#B*P``"B`Q">,",$#C`("3Y0``6.,H```*`%#9Y0%PH.$``%7C/0!5
M$P%0H!,`4*`#$0``&@!`F.4``%3C#```"@A@H.$$`*#A!2"@X0D0H.$-___K
M``!0XP(``!H%,-3G/0!3XPL```H$0+;E``!4X_/__QH$`*#A\(>]Z`E0H.$!
M,/7E``!3XST`4Q/[__\:"5!%X.;__^H(8$;@`5"%X@5`A.!&8:#A!`"@X0!@
MA^7PA[WH"4"@X>W__^H(0*#AZ___ZO!!+>D`4%#B2#&?Y7C03>(`,)/E=#"-
MY0`PH.,"```*`##5Y0``4^,'```:)#&?Y0`@D^5T,)WE`B`SX``PH.-#```:
M>-"-XO"!O>AZ_O_K`$!0XO3__PH<=`3C`7!`XP0`H.'+_O_K``!0XRH```H3
M,-#E$V"`XBX`4^,"```:`3#6Y0``4^/T__\*$S#0Y2X`4^,E```*!0"@X7[^
M_^L`@*#A!@"@X7O^_^L``(C@`@"`XF;^_^L',*#A`1"@XP1@C>4`(.#C`&"@
MX0!0C>6`_O_K"""-X@80H.$#`*#CM?[_ZP$`<.,&`*#A`P``"A@PG>4/.@/B
M`0E3XQ(```HU_O_K!@"@X17^_^L$`*#AH/[_ZP``4./4__\:!`"@X;3^_^L%
M`*#A%O[_Z[[__^H!,-;E+@!3X];__QH",-;E``!3X\7__PK2___JJ___Z^O_
M_^H:_O_K_(X"`!!`+>D`0*#A>#"?Y7#03>(#`*#C#2"@X000H.$`,)/E;#"-
MY0`PH..8_O_K``!0XP``H!,$```:$#"=Y0\Z`^(*"E/C`0E3$P<```HT,)_E
M`""3Y6PPG>4"(#/@`#"@XP<``!IPT(WB$("]Z`(0H.,$`*#A9/[_ZQ`/;^&@
M`J#A\?__ZO?]_^O\C@(`$$`MZ0!`H.$I_O_K`3!`X@,PA.`#`%3A`R"@,0,`
M`#HF``#J`C"@X00`4N$C```*`C"@X0$04N0O`%'C^/__"@,`5.$=```J`3!#
MX@,`5.$<```*`"#3Y2\`4N/Y__\:`3!#X@,``.H`$-+E`3!#XB\`4>,"```:
M`R"@X0,`5.'X__\Z!"!"X`(P@N(!"E/C"```B@$ZH.,!((+B!!"@X4@!">,"
M`$#CQ?W_ZT@!">,"`$#C$("]Z```H.,0@+WH`P!4X>7__QH`,-3E+P!3XP,`
M``HD!`3C`0!`XQ!`O>BZ_?_J[`,$XP$`0.,00+WHMOW_ZO!`+>D!4*#A\!"?
MY0':3>(`8*#A#-!-XO\O`.,!.HWB*`0$XP$`0.,`$)'E!!"#Y0`0H.,$$(WB
M!#"#XKO]_^L`P%#B(P``V@@PC>(!0$SB!."#X`0P7N4``%/C)#$)XP(P0.,`
M<)/E&```&@``5.,;```*!""@X2\0H.,$`(WB_OW_ZP``4.,5```*!P"@X23^
M_^L$,*#A!""-X@80H.$(_O_K`3J-XE`@G^4$,(/B`!"2Y0`@D^4!$#+@`""@
MXPT``!H!VHWB#-"-XO"`O>@,0*#AYO__ZB0Q">,",$#C`'"3Y0<`H.$._O_K
M!2"@X080H.&*_?_KZ?__ZGG]_^O\C@(`\$<MZ0%`H.'T,9_E"-!-X@!0H.$`
M,)/E!#"-Y0`PH.,`,-'E/0!3XP%`@0($`*#AH?W_ZPT0H.$`8*#A!0"@X</^
M_^L`D%#B/@``"IK]_^L``%;A-0``F@!PG>4@@0GC`H!`XP=QH.$`,-7E``!3
MXST`4Q,!,*`3`#"@`P4```H%,*#A`2#SY0``4N,]`%(3^___&@4P0^`"`(;B
M`&"8Y0,`@.!R_?_K``!0XP<`AN<6```*`#"8Y04`H.$`()WE`A&3YP$PT.0`
M,,'E``!3XST`4Q,&```*`2"!X@$PT.0"$*#A`3#"Y#T`4^,``%,3^?__&@$@
MH.$],*#C`##!Y0$PU.0!,.+E``!3X_O__QKL,)_E`""3Y00PG>4"(#/@`#"@
MXS4``!H(T(WB\(>]Z`&02>(!,-3D`3#IY0``4^/[__\:\?__ZB"!">,"@$#C
M`'"8Y0`PE^4``%/C)```"@<PH.$$(+/E"1"@X0&0B>(``%+C^O__&@,0@>(!
M$:#A.#$)XP(P0.,`()/E``!2XP\``!H!`*#A`2"@XP`@@^4S_?_K`*!0XMC_
M_PH'$*#A"7&@X0<@H.'N_/_K`*"(Y0$PB>(`(*#C`R&*YP"0C>6D___J!P"@
MX0K]_^L`H*#A``!0XP``B.7(__\*"7&@X?+__^H#D*#A"!"@X]___^KW_/_K
M_(X"`!!`+>DD00GC`D!`XPC03>(``)3E@/W_ZP``E.5^_?_K?#$(XP$P0.,@
M(0'C`2!`XS@4!.,!$$#C,OW_ZP``E.5U_?_K`,"@XP@W!.,!,$#CF"\"XP$@
M0.,($(WH5!0$XP$00.,__?_K"-"-XA"`O>@D,0GC`C!`XQ!`+>D``)/E9?W_
MZWPQ".,!,$#C("$!XP$@0.,X%`3C`1!`XQ!`O>@8_?_J,$`MZ<0@G^4"VDWB
M'-!-X@(ZC>(4,(/B`""2Y0`@@^4`(*#C\_S_ZP$0H.,`P*#A`2`!XP#`C>4,
M`(WB>#0$XP$P0.,$,(WE;#0$XP$P0./]_/_K`1J-X@$JH.,0$('B#`"-XL7\
M_^L`0%#B`%"@LPD``+H!`(3BTOS_ZP!04.(%```*`1J-X@0@H.$0$('BD_S_
MZP`PH.,$,,7G`CJ-XB@@G^44,(/B`!"2Y0`@D^4!$#+@`""@XP,``!H%`*#A
M`MJ-XAS0C>(P@+WHF?S_Z_R.`@#)___J\$<MZ0!0H.$0(I_E0MU-X@%@H.%!
M/8WB$!"-XGP$!.,!`$#C/#"#X@`@DN4`((/E`""@X^7]_^LO$*#C`$"@X04`
MH.'!_/_K``!0XPX```H%$*#AB`0$XP$`0.,&___K!0"@X4$]C>*P(9_E/#"#
MX@`0DN4`()/E`1`RX``@H.-E```:0MV-XO"'O>@%`*#AJ/S_ZY@4!.,!$$#C
M`'"@X08`H.'<_/_K`)!0XN?__PH`,-GE[(,$XP&`0.-\8(WB``!3XSP```H`
M`%3C!```"@D0H.$$`*#A.?S_ZP``4.,K```*"0"@X9+\_^L!$$#B`,"@X0$P
MB>`!(-GG+P!2XPH``!H"`$#B`R"@X0#`B>``H*#C`P!!X`/@3.``P(/@#J##
MY@$0<N4O`%'C^O__"@$PA^(,P(/@`0I<X\/__ZH!*J#C`1"@XP8`H.$(4(WE
M)#0$XP$P0.,`D(WE!#"-Y9PT!.,!,$#C@?S_ZQ`@C>(&$*#A`P"@X[;\_^L`
M`%#C`P``&B`PG>4/.@/B`@E3XQ4```H``*#CF!0$XP$00..=_/_K`)"@X0``
M4..G__\*`##9Y0``4^/"__\:``!4XP(```H`,-3E+@!3XP(```H(D*#A`<"@
MX]3__^H!,-3E``!3X^K__PKX___J`1"@XP8`H.&"_/_K``!0X^3__QH&$*#A
MB`0$XP$`0..:_O_K!@"@X0[\_^N1___J#_S_Z_R.`@``,-#E``!3XQ[_+P$!
M((#B+P!3XP(`H`$!,-+D``!3X_K__QH>_R_A`#!0X@,```H`,-/E``!3XP``
M``H'_O_J[`,$XP$`0./X^__J,$`MZ:1$!.,!0$#CZ.2?Y3303>+D-)_E","-
MXB!1">,"4$#C`#"3Y2PPC>4`,*#C#P"^Z`\`K.@/`+[H#P"LZ``PGN6P,,SA
M!!"-X@0`H.%"_?_K``!0XPP```H$`)WE`!"5Y0`Q@>`$()/E`"&!YP``4N/S
M__\*!#"#X@0@D^4$((/D``!2X_O__QKM___JL$0$XP%`0.,@40GC`E!`XP00
MC>($`*#A+/W_ZP``4.,,```*!`"=Y0`0E>4`,8'@!""3Y0`A@><``%+C\___
M"@0P@^($()/E!""#Y```4N/[__\:[?__ZKA$!.,!0$#C(%$)XP)00.,$$(WB
M!`"@X1;]_^L``%#C#```"@0`G>4`$)7E`#&!X`0@D^4`(8'G``!2X_/__PH$
M,(/B!""3Y00@@^0``%+C^___&NW__^K$1`3C`4!`XR!1">,"4$#C!!"-X@0`
MH.$`_?_K``!0XPP```H$`)WE`!"5Y0`Q@>`$()/E`"&!YP``4N/S__\*!#"#
MX@0@D^4$((/D``!2X_O__QKM___JS$0$XP%`0.,@40GC`E!`XP00C>($`*#A
MZOS_ZP``4.,,```*!`"=Y0`0E>4`,8'@!""3Y0`A@><``%+C\___"@0P@^($
M()/E!""#Y```4N/[__\:[?__ZMQ$!.,!0$#C(%$)XP)00.,$$(WB!`"@X=3\
M_^L``%#C#```"@0`G>4`$)7E`#&!X`0@D^4`(8'G``!2X_/__PH$,(/B!""3
MY00@@^0``%+C^___&NW__^I\1`3C`4!`XR!1">,"4$#C!!"-X@0`H.&^_/_K
M``!0XPP```H$`)WE`!"5Y0`Q@>`$()/E`"&!YP``4N/S__\*!#"#X@0@D^4$
M((/D``!2X_O__QKM___JZ$0$XP%`0.,@40GC`E!`XP00C>($`*#AJ/S_ZP``
M4.,,```*!`"=Y0`0E>4`,8'@!""3Y0`A@><``%+C\___"@0P@^($()/E!""#
MY```4N/[__\:[?__ZO1$!.,!0$#C(%$)XP)00.,$$(WB!`"@X9+\_^L``%#C
M#```"@0`G>4`$)7E`#&!X`0@D^4`(8'G``!2X_/__PH$,(/B!""3Y00@@^0`
M`%+C^___&NW__^H`103C`4!`XR!1">,"4$#C!!"-X@0`H.%\_/_K``!0XPP`
M``H$`)WE`!"5Y0`Q@>`$()/E`"&!YP``4N/S__\*!#"#X@0@D^4$((/D``!2
MX_O__QKM___JB$0$XP%`0.,@40GC`E!`XP00C>($`*#A9OS_ZP``4.,,```*
M!`"=Y0`0E>4`,8'@!""3Y0`A@><``%+C\___"@0P@^($()/E!""#Y```4N/[
M__\:[?__Z@00C>(,!03C`0!`XU/\_^L`$%#B`@``"O0$!.,!`$#C>?W_ZP00
MC>(@!03C`0!`XTK\_^L`$%#B`@``"O`#!.,!`$#C</W_ZP00C>(T!03C`0!`
MXT'\_^L`$%#B#P``"GP$!.,!`$#C9_W_ZZ`6!.,!$$#CS`0$XP$`0.-B_?_K
M>#"?Y0`@D^4L,)WE`B`SX``PH.,7```:--"-XC"`O>@$$(WB1`4$XP$`0.,K
M_/_K`!!0X@,```KH!`3C`0!`XU']_^OH___J"B"@XQD`C>)8%03C`1!`XT7[
M_^L``%#CX?__&B,0C>+H!`3C`0!`XT7]_^O<___JO/K_ZXB!`0#\C@(`$$`M
MZ11!">,"0$#C<#"?Y0C03>(``)3E`#"3Y00PC>4`,*#C`0!PXP<```I0,)_E
M`""3Y00PG>4"(#/@`#"@XPX``!H(T(WB$("]Z`T0H.'H!`3C`0!`X__[_^L`
M`%#C!```"@``T.4P`%#C``!0$P$`H!,``*`#``"$Y>K__^J9^O_K_(X"`!!`
M+>EX^O_K<?K_ZP``4.,``)`5$("]Z'!`+>D`4*#A`#&?Y1C03>)D!03C`0!`
MXQ`0C>(`,)/E%#"-Y0`PH./C^__K`$!0X@X```H`,-3E``!3XPL```H%$*#A
M5OK_ZP``4.,3```*N#"?Y0`@D^44,)WE`B`SX``PH.,H```:&-"-XG"`O>B8
M,)_E`""3Y10PG>4"(#/@`#"@XP40H`%D!00#`0!``QT``!H8T(WB<$"]Z/'\
M_^H%`*#AGOK_ZP!@H.$$`*#AF_K_ZP``AN`"`(#BAOK_ZP$0H.,`(.#CF#0$
MXP$P0.,`4(WE&`"-Z9PT!.,!,$#C`$"@X9WZ_^L@,)_E`""3Y10PG>4"(#/@
M`#"@XP00H`%D!00#`0!``^'__PI.^O_K_(X"`/!/+>D`<*#A4#>?Y0+93>),
M%Y_E_-!-X@S@@^*$0(WB`BF-X@`0D>7T$(+E`!"@X_0@@N('`)/H!P"$Z"10
M@^(/`+[HG,"-XI!`C>(/`*SH`P">Z`,`C.@'`)7H!P"$Z!@0C>)\!`3C`0!`
MXXW[_^L`0%#B`@``"@`PU.4``%/C%0$`&@WZ_^L&^O_K`$!0XNP```H`4)3E
M``!5X^@```H%`*#A6?K_ZX``H.$!`(#B1/K_ZP`@U>4`8*#A``!2XPP```I\
MA03C`8!`XP9`H.$$`*#A`""-Y0@PH.$`(.#C`1"@XP)`A.)7^O_K`2#UY0``
M4N/U__\:\`,$XP$`0..<4(WB`@``Z@0`M>4``%#C#0``"A@0C>)B^__K`$!0
MXOC__PH`,-3E``!3X_7__PKF^__K``!0X_+__PH$`*#A^?G_ZP!`4.(4```:
M`%"@XX20C>+X,(WB!3&#X'1`$^4``%3C#```"@&`A>((@8G@`##4Y0``4^,'
M```*!`"@X0%0A>+1^__K``!0XT```!H$0)CD``!4X_3__QH`0*#C!`"@X224
M!.,!D$#C%_K_ZP"@H.$&`*#A%/K_ZP``BN`!JX#B!*"*X@H`H.']^?_K`1"@
MXP"`H.$`(.#C#&"-Y9`U!.,!,$#C`$"-Y0@PC>6$-03C`3!`XP20C>42^O_K
M!QV@XP@`H.$8^O_K`0!PXP,``!H)^O_K`""0Y1$`4N.A```:&""-X@@0H.$#
M`*#C2OK_ZP!04.(:```*,`$)XP(`0.,`,)?EU"4$XP$@0.,`@(WE`1"@XP!@
MH.,``)#E%/K_ZP(YC>+T))_E]#"#X@`0DN4`()/E`1`RX``@H.,U`0`:!@"@
MX0+9C>+\T(WB\(^]Z`0`H.&C^?_K`$!0XJO__PJ]___J*#"=Y0\Z`^(!"5/C
MX/__&C!`G>5_^?_K``!4X=S__QHH,)WE4S#HYP<-4^/8__\:"@"@X;GY_^L8
M$(WB`&"@X2@&!.,!`$#C[/K_ZP``4..,```*`$"7Y8GY_^L`$*#A!`"@X?'\
M_^L`H%#BA0``"@H`H.&[^?_K`$"@X0,`4.,,``":!`!`XC`6!.,!$$#C``"*
MX%;Y_^L``%#C!0``&@0`5./2```*!$"*X`4P5.4O`%/CS@``"A1!">,"0$#C
M`#"4Y0$`<^-P```*``!3XWX```J@%@3C`1!`X^@$!.,!`$#C\/O_ZPAW!.,!
M<$#CEOG_ZP$0H.,(`(WE\(#-X08`H.%0-@3C`3!`XPQPC>4`(.#C8*8$XP&@
M0..@^?_K#@``ZIOY_^L`,)#E$0!3XQ```!J%^?_K`5"%X@#`H.$*,*#A!""@
MX0$0H.,&`*#A$'"-Y0Q0C>4`$XWHD/G_ZP<=H.,&`*#AEOG_ZP!`H.$!`'#C
MZO__"@@`H.$K^?_K!A"@X7P$!.,!`$#CQOO_ZP8`H.&J_O_KA___Z@5`H.&0
M8(WB^#"-X@0Q@^!H`!/E``!0XRP```H!4(3B!8&&X`,``.H$`)CD``!0XR8`
M``H!4(7B&!"-X@5`H.&'^O_K`#!0XO;__PH`,-/E``!3X_/__PHB^?_K`%!0
MXOW^_QKG___J,`$)XP(`0.,`,)?E`1"@XP0@C>68)03C`2!`XP"`C>4`8*#C
M``"0Y7?Y_^MA___J@O[_ZP(YC>)X(I_E]#"#X@`0DN4`()/E`1`RX``@H..6
M```:!`"@X0+9C>+\T(WB\$^]Z`7Y_^H-`*#C=%4$XP%00.,H^?_K4R"@XP!@
MH.'D_O_J`*"7Y7?__^H8$(WBZ`0$XP$`0.-7^O_K``!0XP``A`4(```*`##0
MY0``4^,P`%,3`3"@$P`PH`,!,*`3`#"$!0`PA!6`__\:"@"@X0`0H.,-^?_K
M`$!0XGO__PH`,.#C$2#@XP)0H.,`4(WE_?C_ZP8@H./T$(WB!`"@X<#X_^OT
M,-WE``!3XP(``!KU,-WE0P!3XT,```H`,*#C`""@XP`PC>4$`*#A`#"@X^WX
M_^ML!`#K`%"@X0(``.KT$(WB!0"@X8<$`.L"*:#C]!"-X@0`H.&J^/_K`"!0
MXO;__\H$`*#AR*"-XDWY_^OX,(WB!1"@X40`0^)\M03C`;!`XT500^(*0*#A
M,7!#XL8$`.L!(/7E!`"@X0`@C>4+,*#A`1"@XP`@X./[^/_K`D"$X@4`5^'U
M__\:`1"@XP8`H.$`!XWH0#8$XP$P0.,`(.#C",<$XP'`0.,,P(WE`,"@X_#`
MS>7L^/_K8/__Z@1`E^4``%3C+?__"@0`H.'7^/_K`P!0XRG__YH$`$#B.!8$
MXP$00.,``(3@<_C_ZP``4.,$H*`!(?__ZO8PW>5!`%/CN/__&O<PW>5#`%/C
MM?__&O@PW>5(`%/CLO__&ODPW>5%`%/CK___&@`PX.,$`*#A`%"-Y3D@X..>
M^/_K]!"-X@0`H.$I(*#C8?C_Z_0@C>(!$*#C!@"@X0@W!.,!,$#C\(#-X?@@
MS>%`-@3C`3!`XP`@X..\^/_K,/__ZG7X_^NL@0$`_(X"`'!`+>DD00GC`D!`
MXSPRG^4(T$WB``"4Y0`PD^4$,(WE`#"@X_GX_^L`4*#A``"4Y?;X_^L-$*#A
M:##5Y6DPP.7,!`3C`0!`X[SY_^L``%#C`@``"@`PT.4Q`%/C8```"E[\_^L`
M`)3EZ/C_ZP,PH.,!(*#C=!8$XP$00.-]^/_K`%!0X@L```H``)3EW_C_ZQ`P
ME>5X)@3C`2!`XP`0D^59^/_K$#"5Y0`PD^4(,)/E`043XU@``!H``)3ET_C_
MZP,PH.,!(*#C@!8$XP$00.-H^/_K`&!0X@L```H-$*#AB`0$XP$`0..4^?_K
M`%!0XC\```H``)3EQ/C_ZQ`PEN4%(*#A`!"3Y3_X_^LX40GC`E!`XP``E.6\
M^/_K`&"@X0``E.6Y^/_K`2"@XX06!.,!$$#C9/C_ZYPF!.,!($#C`!"@X08`
MH.$O^/_K``"4Y:[X_^L`,*#A`""@XPT0H.%\!`3C`0!`XVD@P^5S^?_K`$"@
MX0``4.,(`(7E#P``"@<=H.,$`*#A7OC_ZP$@@.(`,*#A$0!0XP$`4A,E``"*
MJ#"?Y0`@D^4$,)WE`B`SX``PH.,>```:"-"-XG"`O>@$`)7EL_W_ZP!`H.$`
M`%#C"`"%Y>G__QJD!@3C`0!`XT+X_^L!,-#E``!3XYS__PJ:___J.%$)XP)0
M0.,``)3E@OC_ZQ`@EN4$,)7E``"2Y0`0D^4S^O_KO?__Z@``E.5Z^/_K$#"5
MY0`0D^5!^/_KH/__ZN7W_^L$$)7ER`8$XP$`0.,$(*#A`!"1Y2?X_^O\C@(`
M\$`MZ0!P4.)$,9_E#-!-X@`PD^4$,(WE`#"@XS4```H`,-?E``!3XS(```K;
M^?_K`$"@X0`PU.4``%/C!0``"@$@A.(O`%/C`D"@`0$PTN0``%/C^O__&A11
M">,"4$#C`&!7X@%@H!,`,)7E`0!SXR4```H``%/C`&"@`P%@!A(``%;C!P``
M&L0PG^4`()/E!#"=Y0(@,^``,*#C*P``&@S0C>+P@+WH`##7Y0``4^/T__\*
M!""@XP0`H.&0%03C`1!`XRWX_^L``%#C[?__&GPPG^4`()/E!#"=Y0(@,^``
M,*#C&0``&@<`H.$,T(WB\$"]Z"_Y_^KL`P3C`0!`XYKW_^L`0*#AR?__Z@T0
MH.'H!`3C`0!`X_/X_^L``%#C``"%!=?__PH`,-#E``!3XS``4Q,`,*`#`3"@
M$P`PA070__\*`3"@XP`PA>7+___JB??_Z_R.`@``````\$\MZ4`0@.)L/)_E
MH]]-XH!@@.(-(*#A`#"3Y80RC>4`,*#C`%"@XQ`0$>D$4(+E#%""Y1`@@N(T
M3[_F$$`"Y2PTH.$,Y*#A_SP#X@@0@>(L/(/A_^@.X@P\@^$&`%'A#C"#X0@P
M`N7N__\:",!-XGY/C>(`,*#C#."@X0A@O.5P()[E2)">Y700GN5,@)[E"2`B
MX!APGN4<4)[E"!`AX`3@G.4'("+@!B`BX`40(>`.$"'@`N"2X*(OH.$$`%SA
M@2""X80PC.4"(([A@"",Y>C__QH(4)#E`&"0Y0P@D.4$X)#E)<&@X0`0G>6F
MG:#A(("0Y0+/C.&9*0?C@BI%XQ!`D.6.DHGA&'"0Y0(0D>"&DHGA"!"1X`$0
MF>`'D"3@!9`)X`7/C.$'D"G@#(`DX`F0D>`($)WE!H`(X`(0D>`$@"C@!Q"1
MX`B`D>`F$:#A#A^!X>F-B.`&KX'A$!"=Y0K@+.`"$)'@">`.X`00D>`,X"[@
M#N"1X!@0G>5ID:#AZ.V.X`(0D>`,$)'@"<`JX`C`#.!H@:#A"L`LX`S`D>`@
M$)WE[LV,X`(0D>`*$)'@"*`IX`Z@"N!NX:#A":`JX`H0D>`HH)WE[!V!X`*@
MFN`)D)K@#J`HX`R@"N!LP:#A"*`JX`J0F>`PH)WEX9V)X`*@FN`(@)K@#*`N
MX`&@"N!A$:#A#J`JX`J`F.`XH)WEZ8V(X`*@FN`.X)K@`:`LX`F@"N!ID:#A
M#*`JX`K@GN!`H)WEZ.V.X`*@FN`,P)K@":`AX`B@"N!H@:#A`:`JX`K`G.!(
MH)WE[LV,X`*@FN`!$)K@"*`IX`Z@"N!NX:#A":`JX`H0D>!0H)WE[!V!X`*@
MFN`)D)K@#J`HX`R@"N!LP:#A"*`JX`J0F>!8H)WEX9V)X`*@FN`(@)K@#*`N
MX`&@"N!A$:#A#J`JX`J`F.!@H)WEZ8V(X`*@FN`.X)K@`:`LX`F@"N!ID:#A
M#*`JX`K@GN!HH)WEZ.V.X`*@FN`,P)K@":`AX`B@"N!H@:#A`:`JX`K`G.!P
MH)WE[LV,X`*@FN`!$)K@"*`IX`Z@"N!NX:#A":`JX`H0D>!XH)WE[!V!X`*@
MFN`)D)K@#J`HX`R@"N!LP:#A"*`JX`J0F>"`H)WEX9V)X`*@FN`(@)K@#*`N
MX`&@"N!A$:#A#J`JX`&P+.`*@)C@B*"=Y0FP"^#IC8C@`J":X`RP*^`.X)K@
MD*"=Y6F1H.$+X)[@`J":X.CMCN`,P)K@":`AX`B@"N!H@:#A`:`JX*BPG>4*
MP)S@F*"=Y>[-C.`"()K@H*"=Y0$0DN`(("G@#B`"X&[AH.$)("+@`A"1X*$K
M#N/9+D;C[!V!X`*@FN`)H)K@#I`HX`R0*>!LP:#A"9":X`*PF^`(L)O@L*"=
MY0R`+N#AG8G@`8`HX&$1H.$(@)O@`J":X`Z@FN"XL)WE`>`LX.F-B.`)X"[@
M:9&@X0[@FN`"L)O@#+";X,"@G>4)P"'@Z.V.X`C`+.!H@:#A#,";X`*@FN#(
ML)WE`:":X`@0*>#NS8S@#A`AX&[AH.$!$)K@`K";X`FPF^#0H)WE#I`HX.P=
M@>`,D"G@;,&@X0F0F^`"H)K@"*":X-BPG>4,@"[@X9V)X`&`*.!A$:#A"(":
MX`*PF^`.L)O@X*"=Y0'@+.#IC8C@">`NX&F1H.$.X)O@`J":X`R@FN#HL)WE
M"<`AX.CMCN`(P"S@:(&@X0S`FN`"L)O@`;";X/"@G>4($"G@[LV,X`X0(>!N
MX:#A`1";X`*@FN`)H)K@^+"=Y0Z0*.#L'8'@#)`IX&S!H.$)D)K@`K";X`BP
MF^``H9WE#(`NX.&=B>`!@"C@81&@X0B`F^`"H)K@#J":X`BQG>4!X"S@Z8V(
MX`G@+N!ID:#A#N":X`*PF^`,L)O@$*&=Y0G`(>#H[8[@",`LX&B!H.$,P)O@
M`J":X`&@FN`8L9WE"!`IX.[-C.`.$"'@;N&@X0$0FN`"L)O@(*&=Y0F0F^`.
ML"C@[!V!X`RP*^!LP:#A"Y"9X`*@FN`HL9WE"(":X`R@+N#AG8G@`:`JX&$1
MH.$*@)C@`K";X`&@+.`.X)O@Z8V(X#"QG>4)H"K@"J">X&GAH.$"L)O@Z)V*
MX`Z@(>`,P)O@"*`JX&B!H.$*P)S@.*&=Y4"QG>7IS8S@`B":X&FAH.$!$)+@
M""`NX`D@(N`*D(CA`A"1X-PL"^,;+TCC#)`)X`*PF^#L'8'@#N";X`JP".`+
MD(GA;,&@X0F0GN!(X9WE#+"*X>&=B>`"X)[@`;`+X`C@GN!A@:#A#!`*X`$0
MB^$(L`S@#A"1X%#AG>7I'8'@`N">X`J@GN`(X(SA">`.X&F1H.$+X([A";"(
MX0K@GN!8H9WEX>V.X`&P"^`"H)K@#*":X&'!H.$)$`C@`1"+X0RPB>$*$)'@
M8*&=Y>X=@>`.L`O@`J":X`B@FN!N@:#A#.`)X`[@B^$(L(SA"N">X`&P"^#A
MK8[@:.&=Y0+@GN`)D)[@8>&@X0@0#.`!$(OA#K"(X0D0D>!PD9WE"K`+X`*0
MF>`,D)G@ZLV!X&H1H.$.H`C@"J"+X0&P#N`)D)K@>*&=Y>R=B>`"H)K@"(":
MX`&@CN$,H`K@;,&@X0N@BN$,L`'@"(":X("AG>7IC8C@`J":X`[@FN`,H('A
M":`*X&F1H.$+H(KA";`,X`[@FN"(H9WEZ.V.X`*@FN`!$)K@":",X0B@"N!H
M@:#A"Z"*X0BP">`!H)K@D!&=Y0(0D>`,$)'@[LV*X`B@B>$.H`K@;N&@X0N@
MBN$.L`C@`1":X)BAG>7L'8'@`J":X`F0FN`.H(CA#*`*X&S!H.$+H(KA#+`.
MX`F@FN"@D9WE`I"9X`B0F>#AC8K@#*".X0&@"N!A$:#A"Z"*X0&P#.`)D)K@
MJ*&=Y>B=B>`"H)K@#N":X`&@C.$(H`K@:(&@X0N@BN$(L`'@#N":X+"AG>7I
M[8[@`J":X`S`FN`(H('A":`*X&F1H.$+H(KA";`(X`S`FN"XH9WE[LV,X`*@
MFN`!$)K@":"(X0Z@"N!NX:#A"Z"*X0ZP">`!$)K@P*&=Y>P=@>`"H)K@"(":
MX`Z@B>$,H`K@;,&@X0N@BN$,L([A"(":X,BAG>7AC8C@`;`+X`*@FN`$,(#E
M"9":X&&AH.$,$`[@##"`Y0$0B^$*L`S@"1"1X-"1G>7H'8'@%#"`Y0*0F>`<
M,(#E#I"9X`K@C.$(X`[@:(&@X0O@CN'@L9WE">">X-B1G>7A[8[@`B"9X`B0
M"N`,P)+@"""*X0$@`N!A$:#A"2""X0&0*.`,P)+@UB$,XV(J3.,.D"G@`K";
MX.[-C.`*H)O@Z+&=Y6[AH.$)H)K@`K";X/"1G>4(L)O@#H`AX`R`*.#LK8K@
M"(";X&S!H.$"D)G@^+&=Y0&0F>`,$"[@"A`AX.J-B.`!$)G@:J&@X0*PF^``
MDIWE#K";X`K@+.`(X"[@Z!V!X`[@F^!H@:#A`I"9X`BRG>4,D)G@",`JX`'`
M+.#A[8[@#,"9X&$1H.$"L)O@$)*=Y0JPF^`!H"C@#J`JX.[-C.`*H)O@;N&@
MX0*0F>`8LIWE")"9X`Z`(>`,@"C@[*V*X`B`F>!LP:#A`K";X""2G>4!L)O@
M#!`NX`H0(>#JC8C@`1";X&JAH.$"D)G@*+*=Y0Z0F>`*X"S@".`NX.@=@>`.
MX)G@:(&@X0*PF^`PDIWE#+";X`C`*N`!P"S@X>V.X`S`F^!A$:#A`I"9X#BR
MG>4*H)G@`9`HX`Z0*>#NS8S@":":X&[AH.$"L)O@0)*=Y0BPF^`.@"'@#(`H
MX.RMBN`(@)O@;,&@X0*0F>!(LIWE`9"9X`P0+N`*$"'@ZHV(X`$0F>!JH:#A
M`K";X%"2G>4.L)O@"N`LX`C@+N#H'8'@#N";X&B!H.$"D)G@6+*=Y0R0F>`(
MP"K@`<`LX.'MCN`,P)G@81&@X0*PF^!@DIWE"K";X`&@*.`.H"K@[LV,X`J@
MF^!NX:#A`I"9X&BRG>4(D)G@#H`AX.RMBN`,@"C@;,&@X0B`F>`"L)O@#)`N
MX.J-B.`*D"G@`1";X'"RG>4)$)'@:J&@X>@=@>`*D"S@`K";X`B0*>!A083@
M$$"`Y7A"G>4.X)O@">">X&B!H.$"()3@!F"2X.$MCN`(X"K@#,"6X`X0(>`!
MP)S@!5"2X.(MC.``((#E(""0Y0=PF.`(4(#E`J":X!AP@.4@H(#E)#"`Y1PP
MG^4`()/EA#*=Y0(@,^``,*#C`0``&J/?C>+PC[WH:/3_Z_R.`@`00"WI@`"@
MXXCT_^L/>Y_M`""@XW@@@.4`>X#M#7N?[0)[@.T->Y_M!'N`[0U[G^T&>X#M
M#7N?[0A[@.T->Y_M"GN`[0Q[@.T0@+WH`/`@XP$C16<`````B:O-[P````#^
MW+J8`````'94,A``````\.'2PP```````````````/!'+>D"D*#A`,"@XR@P
MD.4`4*#A+&"0Y0%`H.$P()#EB>&#X#00D.4#`%[AR0^@X08PW.`"```J`3"2
MX@,@H.$`$*'BJ3Z@X3B`A>*`,8/A*."%Y0(PD^`LP(7EH!ZAX'@`E>4P,(7E
M``!0XS00A>4@```:/P!9XR\``-I`D$GB*6.@X0%PAN('<X3@!!"@X0@PH.%`
M0(3B`."1Y1`0@>(,P!'E$#"#X@@`$>4$(!'E!`!1X1#@`^4,P`/E"``#Y00@
M`^7S__\:`4"@X04`H.&*_/_K!P!4X>O__QH&DTG@"2"@X0<0H.$(`*#A]O/_
MZWB0A>7PA[WH0&!@X@00H.$&`%GA``"(X`E@H+$&(*#A[?/_ZW@PE>4#,(;@
M>#"%Y4``4^/PA[T8!0"@X0:02>`&0(3@<?S_Z\W__^H$<*#AYO__ZO!!+>DX
M<('B`4"@X2@PD>4`4*#A,&"1Y7\0X.,SC[_FTS'EYS9OO^8!((/B.`!2XP(`
MA^`#$,?G/```VD`@8N(`$*#C-?3_ZP0`H.%:_/_K!P"@X3@@H.,`$*#C+_3_
MZP0`H.%P8(3E=("$Y5+\_^L#,-3E`##%Y00`H.&R,-3A`3#%Y0`PE.4C-*#A
M`C#%Y0`PE.4#,,7E"S#4Y00PQ>6Z,-3A!3#%Y0@PE.4C-*#A!C#%Y0@PE.4'
M,,7E$S#4Y0@PQ>6R,=3A"3#%Y1`PE.4C-*#A"C#%Y1`PE.4+,,7E&S#4Y0PP
MQ>6Z,=3A#3#%Y1@PE.4C-*#A#C#%Y1@PE.4/,,7E(S#4Y1`PQ>6R,M3A$3#%
MY2`PE.4C-*#A$C#%Y2`PE.43,,7E\$&]Z)+S_^HX(&+B`!"@X_CS_^O'___J
M\$<MZ0!PH.%,8)_E3%"?Y0&`H.$&8(_@`I"@X050C^!K\__K!6!&X$9AL.'P
MA[T(!%!%X@!`H.,$,+7E"2"@X0@0H.$'`*#A`4"$XC/_+^$$`%;A]___&O"'
MO>@03`$`!$P!`![_+^$(,)_E`S"/X``PD^6+\__JT$T!``A`+>D(@+WH`0`"
M`#H````]````"@```#T````/````/0```"0````]````,@```#T````"````
M/0````4````]````$P```#T````-````/0````P````]````(P```#T````1
M````/0```"8````]`````0```#T````7````/0````@````]````"0```#T`
M`````````````"]T;7``````+@```%!!4E]435!$25(``%1%35!$25(`5$U0
M`%5315(`````55-%4DY!344`````)7,O)7,````O````+W!R;V,O<V5L9B]E
M>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!
M4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`4$%27U1%35``````4$%27U!2
M3T=.04U%`````#H````E<R5S)7,``%!%4DPU3$E"`````%!%4DQ,24(`4$52
M3#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!
M3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT``$Q$7TQ)0E)!4EE?
M4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*``!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`
M````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4Q````56YA8FQE
M('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@`````M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E
M;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I
M;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R
M7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@
M)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H
M"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+
M(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@
M7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M
M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP
M<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB
M.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^
M9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*
M<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C
M97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*
M?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN
M960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]
M/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G
M7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP
M*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[
M7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@
M;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US
M("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M
M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?
M<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ
M92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD
M;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA
M9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P*3L*<F5A
M9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@
M,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`[
M"B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D
M(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E
M860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI
M;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA
M;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H
M)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN
M+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^
M("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M
M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@
M)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA
M;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<
M;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B
M=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U
M;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D:6YF;RT^
M>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN<&TB+"`D
M:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@
M9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D[
M"G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N
M;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@
M("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?
M1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A
M<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@
M("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P
M87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A
M;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6
M>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R
M;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%2
M1U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@
M;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS
M:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B
M)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*
M)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T
M(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS
M:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!
M4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D
M14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@
M;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I
M.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R
M)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@
M7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O
M<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@
M;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"([
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].
M3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD
M9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@
M/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E
M;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V
M86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.
M5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]
M>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H
M*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD
M968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E
M7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P
M('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O
M<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#
M.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@
M)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N
M86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA
M;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?
M.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI
M('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H
M;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@
M/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B
M*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T
M96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^
M("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG
M("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N
M+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N
M="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F
M:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)
M3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N
M86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q
M*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^
M<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I
M.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A
M)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@
M>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L
M("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*
M?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N
M86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C
M:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE
M;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M
M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([
M"D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@
M9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J
M(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-
M4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$[
M"FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%2
M7U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@
M+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ
M<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X
M:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R
M86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O
M9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE
M*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8[
M"FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS
M>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@
M>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY
M("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@(CPB
M+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]
M"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!
M4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S
M=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H
M)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]
M("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM
M>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^
M)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D
M(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D
M9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*
M<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N
M86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE
M('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!
M4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P
M<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H
M)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@
M/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@
M*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@
M)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R
M;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@
M;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[
M4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D
M:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E
M;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I
M"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U
M8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%2
M7U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O
M;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,
M25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.
M($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?
M)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@
M>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF
M(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE
M86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H
M)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE
M;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V
M86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB
M*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#
M3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````'!E<FQX<VDN8P```%]?14Y6
M7U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````.1#`0#L0P$``````/!#
M`0#T0P$`_$,!`(!$`0`$1`$```````A$`0`01`$``````#H````]````"@``
M`#T````/````/0```"0````]````,@```#T````"````/0````4````]````
M$P```#T````-````/0````P````]````(P```#T````1````/0```"8````]
M`````0```#T````7````/0````@````]````"0```#T``````````````'R3
M_W\!````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#4%@$`K!8!```````!````(@,```$````R`P```0```$(#
M```!````3`,```P```"@$`$`#0```$A#`0`9````](X"`!L````$````&@``
M`/B.`@`<````!````/7^_V^T`0$`!0```/P)`0`&````/`4!``H```""`P``
M"P```!`````5``````````,`````D`(``@```/@!```4````$0```!<```"H
M#@$`$0```'@.`0`2````,````!,````(````_O__;Q@.`0#___]O`P```/#_
M_V]^#0$`````````````````````````````````````````````````````
M`````````````(\"````````````K!`!`*P0`0"L$`$`K!`!`*P0`0"L$`$`
MK!`!`*P0`0"L$`$`K!`!`*P0`0"L$`$`K!`!`*P0`0"L$`$`K!`!`*P0`0"L
M$`$`K!`!`*P0`0"L$`$`K!`!`*P0`0"L$`$`K!`!`*P0`0"L$`$`K!`!`*P0
M`0"L$`$`K!`!`*P0`0"L$`$`K!`!`*P0`0"L$`$`K!`!`*P0`0"L$`$`K!`!
M`*P0`0"L$`$`K!`!`*P0`0"L$`$`K!`!`*P0`0"L$`$`K!`!`*P0`0"L$`$`
MK!`!`*P0`0"L$`$`K!`!`*P0`0"L$`$`K!`!`*P0`0"L$`$`K!`!`*P0`0"L
M$`$`````````````````_____Q1'`0!'0T,Z("A-86=E:6$@,3`N,BXQ+3`N
M,C`R,#$R,#4N,2YM9V$X*2`Q,"XR+C$@,C`R,#$R,#4`1T-#.B`H36%G96EA
M(#$P+C(N,2TP+C(P,C`Q,C$R+C$N;6=A."D@,3`N,BXQ(#(P,C`Q,C$R`$$R
M````865A8FD``2@````%-RU!``8*!T$(`0D""@02!!,!%`$5`1<#&`$9`1H"
M'`$B`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO
M=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R
M<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N
M=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET
M7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD871A+G)E;"YR;P`N9'EN86UI8P`N9V]T
M`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````
M````````````````````````````````````````````"P````$````"````
M5`$!`%0!```9```````````````!`````````!,````'`````@```'`!`0!P
M`0``)```````````````!``````````F````!P````(```"4`0$`E`$``"``
M``````````````0`````````-````/;__V\"````M`$!`+0!``"(`P``!0``
M```````$````!````#X````+`````@```#P%`0`\!0``P`0```8````!````
M!````!````!&`````P````(```#\"0$`_`D``((#``````````````$`````
M````3@```/___V\"````?@T!`'X-``"8````!0`````````"`````@```%L`
M``#^__]O`@```!@.`0`8#@``8`````8````#````!`````````!J````"0``
M``(```!X#@$`>`X``#`````%``````````0````(````<P````D```!"````
MJ`X!`*@.``#X`0``!0```!8````$````"````'P````!````!@```*`0`0"@
M$```#```````````````!`````````!W`````0````8```"L$`$`K!````@#
M``````````````0````$````@@````$````&````N!,!`+@3``"0+P``````
M```````(`````````(@````!````!@```$A#`0!(0P``"```````````````
M!`````````".`````0````(```!00P$`4$,``!P_``````````````0`````
M````E@````$``'""````;((!`&R"```(````#0`````````$`````````*$`
M```!`````@```'2"`0!T@@``!```````````````!`````````"K````#@``
M``,```#TC@(`](X```0```````````````0````$````MP````\````#````
M^(X"`/B.```$```````````````$````!````,,````!`````P```/R.`@#\
MC@``!```````````````!`````````#0````!@````,`````CP(``(\````!
M```&``````````0````(````V0````$````#`````)`"``"0```,`0``````
M```````$````!````-X````!`````P````R1`@`,D0``$```````````````
M!`````````#D````"`````,````@D0(`')$``"@0``````````````@`````
M````Z0````$````P`````````!R1``!N```````````````!`````0```/(`
M```#``!P``````````"*D0``,P```````````````0`````````!`````P``
A````````````O9$```(!``````````````$`````````
